jQuery accordion form with validation

# Help me Buy and Sell a House

## This form is quick & easy to complete - in only 3 steps!

- Step 1 of 3
  *Required Field

  ### Tell us about the property you're buying

  Are you currently working with a
  real estate agent? No: Yes:
  When would you like to move?
  Purchase price range:
  State:
  Desired property type:
- Step 2 of 3
  *Required Field

  ### Tell us about the property you're selling

  When would you like to sell?
  Type of property you are selling:
  Property Street Address:
  Address (2):
  City:
  State:
  Zip:
  Estimated Market Value:
  Bedrooms:
  Bathrooms:
  Approx. Age of Home:
  Approx. Square Footage:
- Step 3 of 3
  *Required Field

  ### Tell us about yourself

  First Name:
  Last Name:
  Current Address:
  Address (2):
  City:
  State:
  Zip:
  Phone Number:
  Alternate Number:
  Email Address:
  Confirm Email:

  This is a sample form, no information is sent anywhere.